@@ -3,7 +3,7 @@ def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch,
 	import pandas as pd
 	import numpy as np
 	import gc
-	from load_models_quick import create_model
+	from quick_ml.load_models_quick import create_model
 	print("Num classes => " , n_class)
 	print("\n\n", '#'*90, '\n\n')
 	print("\n\n TO OBTAIN THE BEST PERFORMANCE, PLEASE USE THE PRETRAINED MODEL WEIGHTS AS INPUT. Dataset Link -> https://www.kaggle.com/superficiallybot/tf-keras-pretrained-weights\n\n")
